@@ -5,6 +5,7 @@ Alerting for SimpleMonitor
 
 import datetime
 import logging
+import os
 import textwrap
 from enum import Enum
 from socket import gethostname
@@ -18,6 +19,7 @@ from ..util import (
     check_group_match,
     format_datetime,
     get_config_option,
+    short_hostname,
     subclass_dict_handler,
 )
 
@@ -157,8 +159,13 @@ class Alerter:
         self._only_failures = self.get_config_option(
             "only_failures", required_type="bool", default=False
         )
-        self._tz = cast(str, self.get_config_option("tz", default="UTC"))
-        self._times_tz = cast(str, self.get_config_option("times_tz", default="local"))
+        self._tz = cast(
+            str, self.get_config_option("tz", default=os.environ.get("TZ", "UTC"))
+        )
+        self._times_tz = cast(
+            str,
+            self.get_config_option("times_tz", default=os.environ.get("TZ", "local")),
+        )
         self.urgent = cast(
             bool,
             self.get_config_option("urgent", default=self.urgent, required_type="bool"),
@@ -393,14 +400,23 @@ class Alerter:
         else:
             downtime = ""
 
+        host = " on {}".format(
+            monitor.running_on if monitor.is_remote() else self.hostname
+        )
+
         max_length = None  # type: Optional[int]
         if length == AlertLength.NOTIFICATION:
-            message = "Monitor {monitor.name} {alert_verb}".format(
-                monitor=monitor, alert_verb=Alerter._get_verb(alert_type)
+            message = "Monitor {monitor.name}{host} {alert_verb}".format(
+                monitor=monitor,
+                alert_verb=Alerter._get_verb(alert_type),
+                host=host,
             )
         elif length in [AlertLength.SMS, AlertLength.ONELINE]:
+            host = " on {}".format(
+                monitor.running_on if monitor.is_remote() else short_hostname()
+            )
             message = (
-                "{alert_type}: {monitor.name} {alert_verb} on {monitor.running_on} "
+                "{alert_type}: {monitor.name}{host} {alert_verb} "
                 "at {failure_time} ({downtime}): {result}"
             ).format(
                 alert_type=alert_type.value,
@@ -408,6 +424,7 @@ class Alerter:
                 downtime=downtime,
                 failure_time=format_datetime(monitor.first_failure_time(), self._tz),
                 monitor=monitor,
+                host=host,
                 result=monitor.get_result(),
             )
             if length == AlertLength.SMS:
@@ -446,10 +463,6 @@ class Alerter:
                 raise ValueError(
                     "Can't write a message for AlertType {}".format(alert_type)
                 )
-            if monitor.is_remote():
-                host = " on {}".format(monitor.running_on)
-            else:
-                host = ""
             message = message.format(
                 alert_type=alert_type,
                 monitor=monitor,
