@@ -18,9 +18,8 @@ from requests.auth import HTTPBasicAuth
 from .monitor import Monitor, register
 
 try:
-    import ping3
+    from icmplib import NameLookupError, SocketPermissionError, ping
 
-    ping3.EXCEPTIONS = True
 except ImportError:
     pass
 
@@ -237,17 +236,21 @@ class MonitorHost(Monitor):
         )
         ping_ms = str(ping_ttl * 1000)
         ping_ttl = str(ping_ttl)
+        self.count = cast(
+            int,
+            self.get_config_option("count", required_type="int", default=1, minimum=1),
+        )
         platform = sys.platform
         if platform in ["win32", "cygwin"]:
-            self.ping_command = "ping -n 1 -w " + ping_ms + " %s"
+            self.ping_command = f"ping -n {self.count} -w " + ping_ms + " %s"
             self.ping_regexp = r"Reply from [0-9a-f:.]+:.+time[=<]\d+ms"
             self.time_regexp = r"Average = (?P<ms>\d+)ms"
         elif platform.startswith("freebsd") or platform.startswith("darwin"):
-            self.ping_command = "ping -c1 -t" + ping_ttl + " %s"
+            self.ping_command = f"ping -c{self.count} -t" + ping_ttl + " %s"
             self.ping_regexp = "bytes from"
             self.time_regexp = r"min/avg/max/stddev = [\d.]+/(?P<ms>[\d.]+)/"
         elif platform.startswith("linux"):
-            self.ping_command = "ping -c1 -W" + ping_ttl + " %s"
+            self.ping_command = f"ping -c{self.count} -W" + ping_ttl + " %s"
             self.ping_regexp = "bytes from"
             self.time_regexp = r"min/avg/max/stddev = [\d.]+/(?P<ms>[\d.]+)/"
         else:
@@ -388,26 +391,36 @@ class MonitorPing(Monitor):
         self.timeout = cast(
             int, self.get_config_option("timeout", required_type="int", default=5)
         )
+        self.count = cast(
+            int,
+            self.get_config_option("count", required_type="int", default=1, minimum=1),
+        )
 
     def run_test(self) -> bool:
-        if "ping3" not in sys.modules:
-            return self.record_fail("Missing required ping3 module")
+        if "icmplib" not in sys.modules:
+            return self.record_fail("Missing required icmplib module")
         try:
-            response_time = ping3.ping(self.host, timeout=self.timeout, unit="ms")
-            return self.record_success("Ping time {:0.3f}ms".format(response_time))
-        except ping3.errors.PingError as excepton:
-            return self.record_fail(str(excepton))
-        except PermissionError:
+            result = ping(self.host, count=self.count, timeout=self.timeout)
+            if result.is_alive:
+                return self.record_success(
+                    "RTT for {}: {:0.3f}ms".format(result.address, result.avg_rtt)
+                )
+            return self.record_fail(f"Host {result.address} is not alive")
+        except NameLookupError:
+            return self.record_fail(f"Failed to resolve {self.host}")
+        except SocketPermissionError:
             return self.record_fail(
                 "ping monitor requires root to work; "
                 "try the 'host' monitor if this is not an option for you"
             )
 
     def get_params(self) -> Tuple:
-        return (self.host, self.timeout)
+        return (self.host, self.timeout, self.count)
 
     def describe(self) -> str:
-        return "Checking {} pings within {} seconds".format(self.host, self.timeout)
+        return "Checking {} pings within {} seconds ({} attempt(s))".format(
+            self.host, self.timeout, self.count
+        )
 
 
 @register
@@ -460,7 +473,7 @@ class MonitorTLSCert(Monitor):
                     return self.record_fail("SSL Error: {}".format(error.reason))
                 cert = ssl_sock.getpeercert()
                 if not cert:
-                    return self.record_fail("Did not receive certifcate")
+                    return self.record_fail("Did not receive certificate")
                 not_after = str(cert["notAfter"])
                 expiry = datetime.datetime.strptime(not_after, r"%b %d %H:%M:%S %Y %Z")
                 delta = expiry - datetime.datetime.utcnow()
